@@ -1,4 +1,4 @@
-/* Time-stamp: <2008-05-04 21:49:11 poser>
+/* Time-stamp: <2008-08-30 21:21:02 poser>
  *
  * Convert text containing various 7-bit ASCII escapes to UTF-7 Unicode.
  *
@@ -41,7 +41,7 @@
 
 #if defined(__DATE__) && defined(__TIME__)
 #define HAVE_DATE_TIME
-char compdate[]= "Compiled " __DATE__ " " __TIME__ ;
+char compdate[]= __DATE__ " " __TIME__ ;
 #else
 char compdate[]= "";
 #endif
@@ -55,12 +55,37 @@ char pgname[]="ascii2uni";
 #define LOCALEDIR "/usr/local/share/locale"
 #endif
 
-void
-ShowVersion(void){
-  fprintf(stderr,"\n%s  %s\n",pgname,version);
-#ifdef HAVE_DATE_TIME
-  fprintf(stderr,"%s\n",compdate);
+#include <sys/utsname.h>
+
+#ifdef HAVE_GNU_LIBC_VERSION_H
+#include <gnu/libc-version.h>
 #endif
+
+void
+ShowVersion(FILE *fp)   
+{
+  extern char version[];
+  char *vp;
+  char vnum[11+1];
+  struct utsname utsbuf;
+
+  fprintf(fp,"%s %s\n",pgname,version);
+#ifdef HAVE_GNU_LIBC_VERSION_H
+  fprintf(fp,_("  glibc        %s\n"),gnu_get_libc_version());
+#endif
+
+  if (uname(&utsbuf) >= 0) {
+    fprintf(fp,_("Compiled %s on %s\nunder %s %s %s\n"),
+	    compdate,
+	    utsbuf.machine,
+	    utsbuf.sysname,
+	    utsbuf.release,
+	    utsbuf.version);
+  }
+  else fprintf(fp,_("Compiled %s\n"),compdate);
+}
+
+void Copyright() {
   fprintf(stderr,"Copyright (C) 2004-2008 William J. Poser\n");
   fprintf(stderr,"This program is free software; you can redistribute\n\
 it and/or modify it under the terms of version 3 of\n\
@@ -276,7 +301,8 @@ int main (int ac, char *av[])
        exit(INFO);
        break; 			/* NOTREACHED */
      case 'v':
-       ShowVersion();
+       ShowVersion(stderr);
+       Copyright();
        exit(INFO);
        break; 			/* NOTREACHED */
      case ':':
@@ -284,7 +310,8 @@ int main (int ac, char *av[])
        exit(BADOPTIONARG);
      default:
        fprintf(stderr,_("%1$s: invalid option flag %2$c\n"),pgname,optopt);
-       ShowVersion();
+       ShowVersion(stderr);
+       Copyright();
        ShowUsage();
        exit(INFO);
      }
@@ -488,69 +515,42 @@ int main (int ac, char *av[])
        }
        else if (FType == CHENT) {
 	 if (AllHTMLP){
-	   if(sscanf(iptr,aHfmt,&num,&NConsumed)) {
+	   if(sscanf(iptr,aHfmt,&num,&NConsumed) > 0) {
 	     if(*(iptr+NConsumed-1) != ';') {
 	       MicrosoftStyle++;
 	       fprintf(stderr,
 		       _("The HTML/HDML entity %1$s at token %2$lu of line %3$lu lacks the requisite final semicolon.\n"),
 		       ExtractSubstring(tmpstr,iptr,iptr+NConsumed-3),TokenNumber,LineNo);
-	       if(StrictP) {
-		 putchar(*iptr++);
-		 continue;
-	       }
-	       else {
-		 putu8(num);
-		 iptr+=NConsumed;
-	       }
-	     }
-	     else {
-	       putu8(num);
-	       iptr+=NConsumed;
+	       if(StrictP) {putchar(*iptr++); continue;}
+	       else {putu8(num);iptr+=NConsumed;}
 	     }
+	     else {putu8(num);iptr+=NConsumed;}
 	     TokenNumber++;
 	     continue;
 	   }
-	   else if(sscanf(iptr,aDfmt,&num,&NConsumed)) {
+	   if(sscanf(iptr,aDfmt,&num,&NConsumed) > 0) {
 	     if(*(iptr+NConsumed-1) != ';') {
 	       MicrosoftStyle++;
 	       fprintf(stderr,
 		       _("The HTML/HDML entity %1$s at token %2$lu of line %3$lu lacks the requisite final semicolon.\n"),
 		       ExtractSubstring(tmpstr,iptr,iptr+NConsumed-3),TokenNumber,LineNo);
-	       if (StrictP) {
-		 putchar(*iptr++);
-		 continue;
-	       }
-	       else {
-		 putu8(num);
-		 iptr+=NConsumed;
-	       }
-	     }
-	     else {
-	       putu8(num);
-	       iptr+=NConsumed;
+	       if (StrictP) {putchar(*iptr++); continue;}
+	       else {putu8(num);iptr+=NConsumed;}
 	     }
+	     else {putu8(num);iptr+=NConsumed;}
 	     TokenNumber++;
 	     continue;
 	   }
 	 }
-	 if(sscanf(iptr,afmt,&enam,&NConsumed)) {
+	 if(sscanf(iptr,afmt,&enam,&NConsumed) > 0) {
 	   if( (num = LookupCodeForEntity(enam))) {
 	     if(*(iptr+NConsumed-1) != ';') {
 	       MicrosoftStyle++;
 	       fprintf(stderr,_("The HTML/HDML entity %1$s at token %2$lu of line %3$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr,iptr+NConsumed-3),TokenNumber,LineNo);
-	       if(StrictP) {
-		 putchar(*iptr++);
-		 continue;
-	       }
-	       else {
-		 putu8(num);
-		 iptr+=NConsumed;
-	       }
-	     }
-	     else {
-	       putu8(num);
-	       iptr+=NConsumed;
+	       if(StrictP) {putchar(*iptr++);continue;}
+	       else {putu8(num);iptr+=NConsumed;}
 	     }
+	     else {putu8(num);iptr+=NConsumed;}
 	     TokenNumber++;
 	   }
 	   else {
