@@ -1,4 +1,4 @@
-/* Time-stamp: <2008-05-04 21:31:42 poser>
+/* Time-stamp: <2008-08-30 20:27:37 poser>
  *
  * Converts UTF-8 Unicode to pure 7-bit ASCII using any of a number
  * of different representations. 
@@ -45,7 +45,7 @@
 
 #if defined(__DATE__) && defined(__TIME__)
 #define HAVE_DATE_TIME
-char compdate[]= "Compiled " __DATE__ " " __TIME__ ;
+char compdate[]=  __DATE__ " " __TIME__ ;
 #else
 char compdate[]= "";
 #endif
@@ -60,12 +60,38 @@ char pgname[]="uni2ascii";
 
 char msg [MSGSIZE];
 
-void
-ShowVersion(void){
-  fprintf(stderr,"\n%s  %s\n",pgname,version);
-#ifdef HAVE_DATE_TIME
-  fprintf(stderr,"%s\n",compdate);
+#include <sys/utsname.h>
+
+#ifdef HAVE_GNU_LIBC_VERSION_H
+#include <gnu/libc-version.h>
 #endif
+
+void
+ShowVersion(FILE *fp)   
+{
+  extern char version[];
+  char *vp;
+  char vnum[11+1];
+  struct utsname utsbuf;
+
+  fprintf(fp,"%s %s\n",pgname,version);
+#ifdef HAVE_GNU_LIBC_VERSION_H
+  fprintf(fp,_("  glibc        %s\n"),gnu_get_libc_version());
+#endif
+
+  if (uname(&utsbuf) >= 0) {
+    fprintf(fp,_("Compiled %s on %s\nunder %s %s %s\n"),
+	    compdate,
+	    utsbuf.machine,
+	    utsbuf.sysname,
+	    utsbuf.release,
+	    utsbuf.version);
+  }
+  else fprintf(fp,_("Compiled %s\n"),compdate);
+}
+
+
+void Copyright (void) {
   fprintf(stderr,"Copyright (C) 2004-2008 William J. Poser\n");
   fprintf(stderr,"This program is free software; you can redistribute\n\
 it and/or modify it under the terms of version 3 of\n\
@@ -2745,6 +2771,7 @@ int main (int ac, char *av[])
   short HexUpperP = 1;	/* Use X or x in  hex ?  */
   short AddWhitespaceP = 0;
   short PassThroughP = 0;	/* If untransformed, pass through unicode rather than asciifying */
+  short AllHTMLP = 0;		/* Not a valid option here - just used to detect bad cl */
 
   short AscifyStyleP = 0;
   short AscifyDiacriticsP = 0;
@@ -2768,7 +2795,6 @@ int main (int ac, char *av[])
   extern void ListFormatArguments(short);
   extern void SetFormat(char *, int *, short *,int *, short *, short *);
 
-
   opterr = 0;
   ByteCnt = 0L;
   CharCnt = 0L;
@@ -2789,8 +2815,8 @@ int main (int ac, char *av[])
   while( (oc = getopt(ac,av,":Aa:BcdeEfhlLnPpqsS:vwyxZ:")) != EOF){
     switch(oc){
     case 'a':
-      SetFormat(optarg,&FType,&UseEntitiesP, &UTF8Type, &BMPSplitP,&dummy);
-       if(FType == FMT_UNKNOWN) {
+      SetFormat(optarg,&FType,&UseEntitiesP, &UTF8Type, &BMPSplitP,&AllHTMLP);
+       if( (FType == FMT_UNKNOWN) || AllHTMLP) {
 	 fprintf(stderr,"Format specification %s not recognized.\n",optarg);
 	 exit(BADOPTIONARG);
        }
@@ -2866,7 +2892,8 @@ int main (int ac, char *av[])
       VerboseP = 0;
       break;
     case 'v':
-      ShowVersion();
+      ShowVersion(stderr);
+      Copyright();
       exit(INFO);
       break; 			/* NOTREACHED */
      case ':':
@@ -2874,7 +2901,8 @@ int main (int ac, char *av[])
        exit(BADOPTIONARG);
     default:
       fprintf(stderr,_("%1$s: invalid option flag %2$c\n"),pgname,optopt);
-      ShowVersion();
+      ShowVersion(stderr);
+      Copyright();
       ShowUsage();
       exit(BADOPTION);
     }
@@ -3189,4 +3217,3 @@ int main (int ac, char *av[])
 }
 
 
-
